searchData={"content_type":"text/markdown","items":[{"doc":"Helps abbreviate writing LiveView `assign/3`, `assign_new/3` and `update/3` wrapper functions.\n\nEx:\n\n```\ndefassign :foo\n```\n\nexpands into\n\n```\ndef assign_foo( socket_or_assigns, foo) do\n  assign( socket_or_assigns, :foo, foo)\nend\n```\n\nwhile\n\n```\ndefassign [ :foo, :bar, :baz]\n```\n\nexpands into\n\n```\ndef assign_foo( socket_or_assigns, foo) do\n  assign( socket_or_assigns, :foo, foo)\nend\n\ndef assign_foo( socket_or_assigns, bar) do\n  assign( socket_or_assigns, :bar, bar)\nend\n\ndef assign_foo( socket_or_assigns, baz) do\n  assign( socket_or_assigns, :baz, baz)\nend\n```\n\nSimilarly,\n\n```\ndefupdate [ :foo, :bar]\n```\n\nexpands into\n\n```\ndef update_foo( socket_or_assigns, updater) do\n  assign( socket_or_assigns, :foo, updater)\nend\n\ndef update_bar( socket_or_assigns, updater) do\n  assign( socket_or_assigns, :bar, updater)\nend\n```\n\nBoolean assigns are an exception in that the assign key is identical to the\nname, while the assign (or update) wrapper function name does not contain the\nquestion mark.\n\nEx:\n\n```\ndefassign :connected?\n```\n\nexpands into:\n\n```\ndef assign_connected( socket_or_assigns, connected?) do\n  assign( socket_or_assigns, :connected?, connected?)\nend\n```","ref":"Assigns.html","title":"Assigns","type":"module"},{"doc":"Defines a `Phoenix.Component.assign/3` wrapper function for each of the names\nwhether provided in a list or as a standalone atom.","ref":"Assigns.html#defassign/1","title":"Assigns.defassign/1","type":"macro"},{"doc":"Defines a `Phoenix.Component.assign_new/3` wrapper function for each of the\nnames whether provided in a list or as a standalone atom.","ref":"Assigns.html#defassign_new/1","title":"Assigns.defassign_new/1","type":"macro"},{"doc":"Same as `defassign_new/1` but defines private wrapper function(s).","ref":"Assigns.html#defassign_newp/1","title":"Assigns.defassign_newp/1","type":"macro"},{"doc":"Same as `defassign/1` but defines private wrapper function(s).","ref":"Assigns.html#defassignp/1","title":"Assigns.defassignp/1","type":"macro"},{"doc":"Defines a `Phoenix.Component.update/3` wrapper function for each of the names\nwhether provided in a list or as a standalone atom.","ref":"Assigns.html#defupdate/1","title":"Assigns.defupdate/1","type":"macro"},{"doc":"Same as `defupdate/1` but defines private  wrapper function(s).","ref":"Assigns.html#defupdatep/1","title":"Assigns.defupdatep/1","type":"macro"},{"doc":"# Assigns\n\nAssigns is a library that enables abbreviation of Phoenix LiveView `assign/3`, `assign_new/3` and `update/3` wrapper \nfunction definitions.","ref":"readme.html","title":"Assigns","type":"extras"},{"doc":"```elixir\ndef deps do\n  [\n    { :assigns, \"~> 0.2.0\"}\n  ]\nend\n```\n\nUse the `Assigns` module in every module where you need it:\n\n```elixir\ndefmodule MyAppWeb.MyLiveView do\n  use MyAppWeb, :live_view\n  \n  use Assigns # insert this here, or better yet into `MyAppWeb.html_helpers/0`\n  \n  # ..\nend\n```","ref":"readme.html#installation","title":"Installation - Assigns","type":"extras"},{"doc":"The docs can be found at [HexDocs](https://hexdocs.pm/assigns).","ref":"readme.html#docs","title":"Docs - Assigns","type":"extras"},{"doc":"```elixir\ndefmodule MyAppWeb.MyLiveView do\n  use MyAppWeb, :live_view\n  use Assigns\n  \n  # ..\n  \n  defassign_newp [ :foo, :baz]\n  defassignp [ :foo, :bar, :baz, :just_mounted?]\n  defupdatep :bar  \nend\n```\n\nThe snippet above is an equivalent of (expands into) the following:\n\n```elixir\ndefmodule MyAppWeb.MyLiveView do\n  use MyAppWeb, :live_view\n  use Assigns\n  \n  # ..\n\n  defp assign_new_foo( socket_or_assigns, fun) do\n    assign_new( socket_or_assigns, :foo, fun)\n  end\n  \n  defp assign_new_baz( socket_or_assigns, fun) do\n    assign_new( socket_or_assigns, :baz, fun)\n  end\n  \n  defp assign_foo( socket_or_assigns, foo) do\n    assign( socket_or_assigns, :foo, foo)\n  end\n  \n  defp assign_bar( socket_or_assigns, bar) do\n    assign( socket_or_assigns, :bar, bar)    \n  end\n  \n  defp assign_baz( socket_or_assigns, baz) do\n    assign( socket_or_assigns, :baz, baz)\n  end\n  \n  defp assign_just_mounted( socket_or_assigns, just_mounted?) do\n    assign( socket_or_assigns, :just_mounted?, just_mounted?)\n  end\n  \n  defp update_bar( socket_or_assigns, updater) do\n    assign( socket_or_assigns, :bar, updater)\n  end\nend\n```","ref":"readme.html#sample-usage","title":"Sample usage - Assigns","type":"extras"},{"doc":"The source code formatting in this library diverges from the standard formatting practice based on using `mix format`\nin so much that there's a leading space character inserted before each initial argument / element with an intention to\nimprove the code readability (subject to the author's personal perception).","ref":"readme.html#formatting","title":"Formatting - Assigns","type":"extras"},{"doc":"# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"- Accept module attribute for the assign name atom list","ref":"changelog.html#v0-2-0-2024-10-01","title":"v0.2.0 (2024-10-01) - Changelog","type":"extras"},{"doc":"- Initial implementation","ref":"changelog.html#v0-1-0-2024-09-28","title":"v0.1.0 (2024-09-28) - Changelog","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}